@@ -152,7 +152,7 @@ gpx_dialog_t *gpx_busy_dialog_new(GtkWidget *parent) {
   dialog->dialog = gtk_dialog_new();
 
   gtk_dialog_set_has_separator(GTK_DIALOG(dialog->dialog), FALSE);
-  gtk_window_set_title(GTK_WINDOW(dialog->dialog), _("Loading..."));
+  gtk_window_set_title(GTK_WINDOW(dialog->dialog), _("Loading"));
   gtk_window_set_default_size(GTK_WINDOW(dialog->dialog), 300, 10);
 
   gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
@@ -764,6 +764,7 @@ static cache_t *process_gpx_wpt(xmlTextReaderPtr reader,  gpx_dialog_t *dialog,
       /* neither geocaching.com GC* nor opencaching.com OC* nor */
       /* geocaching australia GA* waypoint */
       if(cache->id &&
+	 (strncasecmp(cache->id, "__", 2) != 0) &&
 	 (strncasecmp(cache->id, "GC", 2) != 0) &&
 	 (strncasecmp(cache->id, "OC", 2) != 0) &&
 	 (strncasecmp(cache->id, "GA", 2) != 0)) {
@@ -1069,9 +1070,7 @@ static gpx_t *gpx_parse_file(gpx_dialog_t *dialog, char *filename) {
     *dot = 0;
     snprintf(wpts_name, sizeof(wpts_name), "%s-wpts.gpx", filename);
     *dot = '.';
-
     if(g_file_test(wpts_name,  G_FILE_TEST_EXISTS)) {
-
       xmlTextReaderPtr reader = xmlReaderForFile(wpts_name, NULL, 0);
       if (reader != NULL) {
 	gpx = process_root(reader, dialog, wpts_name, gpx);
@@ -1356,7 +1355,6 @@ void gpx_pos_get_distance_str(char *str, int len,
   distance_str(str, len, dist, mil);
 }
 
-/* http://library.gnome.org/devel/gtk/unstable/GtkRadioButton.html */
 void gpx_sort(gpx_t *gpx, int by, pos_t *refpos) {
   cache_t **new;
   cache_t *cur = gpx->cache;
@@ -1365,9 +1363,12 @@ void gpx_sort(gpx_t *gpx, int by, pos_t *refpos) {
 
   gpx->cache = NULL;  /* detach old chain */
   while(cur) {
-    float cur_dist = gpx_pos_get_distance(*refpos, gpx_cache_pos(cur), 0);
+    float cur_dist = -1;
     int cur_cnt = 0;
 
+    if(!isnan(cur->pos.lat) && !isnan(cur->pos.lon)) 
+      cur_dist = gpx_pos_get_distance(*refpos, gpx_cache_pos(cur), 0);
+    
     new = &(gpx->cache);
 
     /* search for currect insertion point */
