@@ -386,6 +386,7 @@ gint notes_destroy_event(GtkWidget *widget, gpointer data ) {
   return FALSE;
 }
 
+#ifndef NO_COPY_N_PASTE
 static void on_destroy_textview(GtkWidget *widget, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
 
@@ -412,6 +413,7 @@ static void on_destroy_textview(GtkWidget *widget, gpointer data) {
     }
   }
 }
+#endif
 
 static void ftime_update(GtkWidget *widget, cache_context_t *context, 
 			 gboolean update) {
@@ -496,6 +498,7 @@ static void callback_modified(GtkWidget *widget, gpointer data ) {
   }
 }
 
+#ifndef NO_COPY_N_PASTE
 static gboolean focus_in(GtkWidget *widget, GdkEventFocus *event,
 			 gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
@@ -514,9 +517,9 @@ static gboolean focus_in(GtkWidget *widget, GdkEventFocus *event,
 
   return FALSE;
 }
+#endif
 
 GtkWidget *cache_notes(cache_context_t *context) {
-  appdata_t *appdata = context->appdata;
   cache_t *cache = context->cache;
 
   context->notes.modified = FALSE;
@@ -594,7 +597,7 @@ GtkWidget *cache_notes(cache_context_t *context) {
   if(cache->notes && cache->notes->text)
     gtk_text_buffer_set_text(context->notes.buffer, cache->notes->text, -1);
 
-#ifndef USE_MAEMO
+#ifndef USE_HILDON_TEXT_VIEW
   GtkWidget *view = gtk_text_view_new_with_buffer(context->notes.buffer);
 #else
   GtkWidget *view = hildon_text_view_new();
@@ -612,10 +615,12 @@ GtkWidget *cache_notes(cache_context_t *context) {
   gtk_text_buffer_set_rich_text_format(context->notes.buffer, "RTF" );
 #endif  
 
+#ifndef NO_COPY_N_PASTE
   g_signal_connect(G_OBJECT(view), "focus-in-event", 
-		   G_CALLBACK(focus_in), appdata);
+		   G_CALLBACK(focus_in), context->appdata);
   g_signal_connect(G_OBJECT(view), "destroy", 
-		   G_CALLBACK(on_destroy_textview), appdata);
+		   G_CALLBACK(on_destroy_textview), context->appdata);
+#endif
 
 #ifndef USE_PANNABLE_AREA
   gtk_container_add(GTK_CONTAINER(scrolled_window), view);
@@ -821,7 +826,7 @@ void notes_log_export(appdata_t *appdata) {
   GtkWidget *label = gtk_label_new(_("Export to:"));
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE,0);
   gtk_misc_set_alignment(GTK_MISC(label), 0.f, 0.5f);
-  GtkWidget *button = gtk_button_new_with_label(_("Browse..."));
+  GtkWidget *button = gtk_button_new_with_label(_("Browse"));
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		     GTK_SIGNAL_FUNC(on_browse), (gpointer)&context);
   gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE,0);
